==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurestack/kotlin/inputs/ListProductDetailsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestack.kotlin.inputs

import com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property productName Name of the product.
 * @property registrationName Name of the Azure Stack registration.
 * @property resourceGroup Name of the resource group.
 */
public data class ListProductDetailsPlainArgs(
    public val productName: String,
    public val registrationName: String,
    public val resourceGroup: String,
) : ConvertibleToJava<com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs =
        com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs.builder()
            .productName(productName.let({ args0 -> args0 }))
            .registrationName(registrationName.let({ args0 -> args0 }))
            .resourceGroup(resourceGroup.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListProductDetailsPlainArgs].
 */
@PulumiTagMarker
public class ListProductDetailsPlainArgsBuilder internal constructor() {
    private var productName: String? = null

    private var registrationName: String? = null

    private var resourceGroup: String? = null

    /**
     * @param value Name of the product.
     */
    @JvmName("gutaurbqamiildvd")
    public suspend fun productName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productName = mapped
    }

    /**
     * @param value Name of the Azure Stack registration.
     */
    @JvmName("swyyxklkxlyuflsb")
    public suspend fun registrationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registrationName = mapped
    }

    /**
     * @param value Name of the resource group.
     */
    @JvmName("irkrvuevpjsnapic")
    public suspend fun resourceGroup(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroup = mapped
    }

    internal fun build(): ListProductDetailsPlainArgs = ListProductDetailsPlainArgs(
        productName = productName ?: throw PulumiNullFieldException("productName"),
        registrationName = registrationName ?: throw PulumiNullFieldException("registrationName"),
        resourceGroup = resourceGroup ?: throw PulumiNullFieldException("resourceGroup"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurestack/kotlin/inputs/ListProductDetailsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurestack.kotlin.inputs

import com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property productName Name of the product.
 * @property registrationName Name of the Azure Stack registration.
 * @property resourceGroup Name of the resource group.
 */
public data class ListProductDetailsPlainArgs(
    public val productName: String,
    public val registrationName: String,
    public val resourceGroup: String,
) : ConvertibleToJava<com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs =
        com.pulumi.azurenative.azurestack.inputs.ListProductDetailsPlainArgs.builder()
            .productName(productName.let({ args0 -> args0 }))
            .registrationName(registrationName.let({ args0 -> args0 }))
            .resourceGroup(resourceGroup.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListProductDetailsPlainArgs].
 */
@PulumiTagMarker
public class ListProductDetailsPlainArgsBuilder internal constructor() {
    private var productName: String? = null

    private var registrationName: String? = null

    private var resourceGroup: String? = null

    /**
     * @param value Name of the product.
     */
    @JvmName("pyeeffcybkdendas")
    public suspend fun productName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.productName = mapped
    }

    /**
     * @param value Name of the Azure Stack registration.
     */
    @JvmName("igbystfgmpmrpdgc")
    public suspend fun registrationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registrationName = mapped
    }

    /**
     * @param value Name of the resource group.
     */
    @JvmName("planhrlgokctdyry")
    public suspend fun resourceGroup(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroup = mapped
    }

    internal fun build(): ListProductDetailsPlainArgs = ListProductDetailsPlainArgs(
        productName = productName ?: throw PulumiNullFieldException("productName"),
        registrationName = registrationName ?: throw PulumiNullFieldException("registrationName"),
        resourceGroup = resourceGroup ?: throw PulumiNullFieldException("resourceGroup"),
    )
}
